@@ -14,6 +14,8 @@ from .openapi_client.configuration import Configuration
 from .openapi_client.model.application_in import ApplicationIn
 from .openapi_client.model.application_out import ApplicationOut
 from .openapi_client.model.dashboard_access_out import DashboardAccessOut
+from .openapi_client.model.endpoint_headers_in import EndpointHeadersIn
+from .openapi_client.model.endpoint_headers_out import EndpointHeadersOut
 from .openapi_client.model.endpoint_in import EndpointIn
 from .openapi_client.model.endpoint_out import EndpointOut
 from .openapi_client.model.endpoint_secret_out import EndpointSecretOut
@@ -34,6 +36,7 @@ from .openapi_client.model.message_attempt_out import MessageAttemptOut
 from .openapi_client.model.message_in import MessageIn
 from .openapi_client.model.message_out import MessageOut
 from .openapi_client.model.message_status import MessageStatus
+from .openapi_client.model.recover_in import RecoverIn
 
 DEFAULT_SERVER_URL = "https://api.svix.com"
 
@@ -194,6 +197,41 @@ class Endpoint(ApiBase[EndpointApi]):
                 _check_return_type=False,
             )
 
+    def recover(self, app_id: str, endpoint_id: str, recover_in: RecoverIn) -> None:
+        with self._api() as api:
+            api.resend_failed_webhooks_api_v1_app_app_id_endpoint_endpoint_id_recover_post(
+                app_id=app_id,
+                endpoint_id=endpoint_id,
+                recover_in=recover_in,
+                _check_return_type=False,
+            )
+
+    def get_headers(self, app_id: str, endpoint_id: str) -> EndpointHeadersOut:
+        with self._api() as api:
+            return api.get_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_get(
+                app_id=app_id,
+                endpoint_id=endpoint_id,
+                _check_return_type=False,
+            )
+
+    def update_headers(self, app_id: str, endpoint_id: str, endpoint_headers_in: EndpointHeadersIn) -> None:
+        with self._api() as api:
+            api.update_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_put(
+                app_id=app_id,
+                endpoint_id=endpoint_id,
+                endpoint_headers_in=endpoint_headers_in,
+                _check_return_type=False,
+            )
+
+    def patch_headers(self, app_id: str, endpoint_id: str, endpoint_headers_in: EndpointHeadersIn) -> None:
+        with self._api() as api:
+            api.patch_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_patch(
+                app_id=app_id,
+                endpoint_id=endpoint_id,
+                endpoint_headers_in=endpoint_headers_in,
+                _check_return_type=False,
+            )
+
 
 class EventType(ApiBase[EventTypeApi]):
     _ApiClass = EventTypeApi
@@ -206,6 +244,12 @@ class EventType(ApiBase[EventTypeApi]):
         with self._api() as api:
             return api.create_event_type_api_v1_event_type_post(event_type_in=event_type_in, _check_return_type=False)
 
+    def get(self, event_type_name: str) -> EventTypeOut:
+        with self._api() as api:
+            return api.get_event_type_api_v1_event_type_event_type_name_get(
+                event_type_name=event_type_name, _check_return_type=False
+            )
+
     def update(self, event_type_name: str, event_type_update: EventTypeUpdate) -> EventTypeOut:
         with self._api() as api:
             return api.update_event_type_api_v1_event_type_event_type_name_put(
@@ -330,6 +374,8 @@ __all__ = [
     "ApplicationOut",
     "ListResponseApplicationOut",
     "DashboardAccessOut",
+    "EndpointHeadersIn",
+    "EndpointHeadersOut",
     "EndpointIn",
     "EndpointOut",
     "EndpointSecretOut",
@@ -353,5 +399,6 @@ __all__ = [
     "EventTypeListOptions",
     "EndpointListOptions",
     "MessageAttemptListOptions",
+    "RecoverIn",
     "Svix",
 ]
